@@ -19,7 +19,7 @@ export default function CodeEnhancer() {
       const btn = document.createElement('button')
       btn.type = 'button'
       btn.textContent = 'Copy'
-      btn.className = 'copy-btn absolute top-2 right-2 text-xs px-2 py-1 rounded bg-gray-700 text-white hover:bg-gray-800 active:bg-gray-900'
+      btn.className = 'copy-btn absolute top-2 right-2 text-xs px-2 py-1 rounded bg-gray-700 text-gray-200 hover:bg-gray-800 active:bg-gray-900'
       btn.addEventListener('click', () => {
         const text = codeEl.innerText
         navigator.clipboard.writeText(text).then(() => {
